@@ -1,7 +1,7 @@
 package # hide
 Data_Test_Arguments;
 
-use 5.008003;
+use 5.10.0;
 use warnings;
 use strict;
 
